csep.core.forecasts.CatalogForecast.get\_expected\_rates
========================================================

.. currentmodule:: csep.core.forecasts

.. automethod:: CatalogForecast.get_expected_rates